==> piwigo-2.5.1.zip: piwigo/plugins/LocalFilesEditor/language/bg_BG/plugin.lang.php <==
<?php
// +-----------------------------------------------------------------------+
// | Piwigo - a PHP based photo gallery                                    |
// +-----------------------------------------------------------------------+
// | Copyright(C) 2008-2013 Piwigo Team                  http://piwigo.org |
// | Copyright(C) 2003-2008 PhpWebGallery Team    http://phpwebgallery.net |
// | Copyright(C) 2002-2003 Pierrick LE GALL   http://le-gall.net/pierrick |
// +-----------------------------------------------------------------------+
// | This program is free software; you can redistribute it and/or modify  |
// | it under the terms of the GNU General Public License as published by  |
// | the Free Software Foundation                                          |
// |                                                                       |
// | This program is distributed in the hope that it will be useful, but   |
// | WITHOUT ANY WARRANTY; without even the implied warranty of            |
// | MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU      |
// | General Public License for more details.                              |
// |                                                                       |
// | You should have received a copy of the GNU General Public License     |
// | along with this program; if not, write to the Free Software           |
// | Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, |
// | USA.                                                                  |
// +-----------------------------------------------------------------------+
$lang['locfiledit_bak_loaded1'] = 'Архивния файл е зареден.';
$lang['locfiledit_bak_loaded2'] = 'Трябва да запишете файла за да го възстановите.';
$lang['locfiledit_cant_save'] = 'Този файл е забранен за запис. Проверете папка "local/" дали е разришен записа(chmod).';
$lang['locfiledit_choose_file'] = 'Избери файл за редактиране';
$lang['locfiledit_edit'] = 'Редакция';
$lang['locfiledit_empty_filename'] = 'Трябва да попълните име на файл.';
$lang['locfiledit_empty_page'] = 'Празна страница';
$lang['locfiledit_file_already_exists'] = 'Файла вече съществува.';
$lang['locfiledit_filename_error'] = 'Забранен символ в името на файла.';
$lang['locfiledit_model_error'] = 'Трябва да изберете модел.';
$lang['locfiledit_model'] = 'Модел';
$lang['locfiledit_new_filename'] = 'Име на файл';
$lang['locfiledit_new_tpl'] = 'Създайте нов файл';
$lang['locfiledit_newfile'] = 'Файлът не съществува и ще бъде създаден от LocalFiles Редактора';
$lang['locfiledit_onglet_css'] = 'CSS';
$lang['locfiledit_onglet_lang'] = 'Езици';
$lang['locfiledit_onglet_localconf'] = 'Local config';
$lang['locfiledit_onglet_plug'] = 'Персонални допълниния';
$lang['locfiledit_onglet_tpl'] = 'Тапети';
$lang['locfiledit_parent_directory'] = 'Главна директория';
$lang['locfiledit_restore_confirm'] = 'Моля потвърдете?
Възстановяването няма да е възможно до следващ запис. ';
$lang['locfiledit_restore'] = 'Възтанови архивния файл';
$lang['locfiledit_save_bak'] = 'Архивно копие ще бъде създадено след записа.';
$lang['locfiledit_save_config'] = 'Файла е записан успешно.';
$lang['locfiledit_save_file'] = 'Запис файл';
$lang['locfiledit_saved_bak'] = 'Архивно копие е създадено (%s)';
$lang['locfiledit_show_default'] = 'Покажи референтния файл:';
$lang['locfiledit_syntax_error'] = 'Синтактична грешка! Файлът не може да бъде записан.';
$lang['locfiledit_webmaster_only'] = 'Само Уебмастъри могат да създават и променят локални файлове.';
?>

==> piwigo-16.0.0.zip: piwigo/plugins/LocalFilesEditor/language/bg_BG/plugin.lang.php <==
<?php
// +-----------------------------------------------------------------------+
// | Piwigo - a PHP based photo gallery                                    |
// +-----------------------------------------------------------------------+
// | Copyright(C) 2008-2014 Piwigo Team                  http://piwigo.org |
// | Copyright(C) 2003-2008 PhpWebGallery Team    http://phpwebgallery.net |
// | Copyright(C) 2002-2003 Pierrick LE GALL   http://le-gall.net/pierrick |
// +-----------------------------------------------------------------------+
// | This program is free software; you can redistribute it and/or modify  |
// | it under the terms of the GNU General Public License as published by  |
// | the Free Software Foundation                                          |
// |                                                                       |
// | This program is distributed in the hope that it will be useful, but   |
// | WITHOUT ANY WARRANTY; without even the implied warranty of            |
// | MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU      |
// | General Public License for more details.                              |
// |                                                                       |
// | You should have received a copy of the GNU General Public License     |
// | along with this program; if not, write to the Free Software           |
// | Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, |
// | USA.                                                                  |
// +-----------------------------------------------------------------------+
$lang['locfiledit_bak_loaded1'] = 'Архивният файл е зареден.';
$lang['locfiledit_bak_loaded2'] = 'Трябва да запишете файла за да го възстановите.';
$lang['locfiledit_cant_save'] = 'Този файл е забранен за запис. Проверете папка "local/" дали е разришен записа(chmod).';
$lang['locfiledit_choose_file'] = 'Избери файл за редактиране';
$lang['locfiledit_edit'] = 'Редакция';
$lang['locfiledit_empty_filename'] = 'Трябва да попълните име на файл.';
$lang['locfiledit_empty_page'] = 'Празна страница';
$lang['locfiledit_file_already_exists'] = 'Файлът вече съществува.';
$lang['locfiledit_filename_error'] = 'Забранен символ в името на файла.';
$lang['locfiledit_model_error'] = 'Трябва да изберете модел.';
$lang['locfiledit_model'] = 'Модел';
$lang['locfiledit_new_filename'] = 'Име на файл';
$lang['locfiledit_new_tpl'] = 'Създайте нов файл';
$lang['locfiledit_newfile'] = 'Файлът не съществува докато не въведете някаква информация отдолу. След като е въведена информация и е записана, файлът ще бъде създаден.';
$lang['locfiledit_onglet_css'] = 'CSS';
$lang['locfiledit_onglet_lang'] = 'Езици';
$lang['locfiledit_onglet_localconf'] = 'Локална конфигурация';
$lang['locfiledit_onglet_plug'] = 'Персонални допълниния';
$lang['locfiledit_onglet_tpl'] = 'Шаблони';
$lang['locfiledit_parent_directory'] = 'Родителска директория';
$lang['locfiledit_restore_confirm'] = 'Моля потвърдете?
Възстановяването няма да е възможно до следващ запис.';
$lang['locfiledit_restore'] = 'Възтанови архивния файл';
$lang['locfiledit_save_bak'] = 'Архивно копие ще бъде създадено след записа.';
$lang['locfiledit_save_config'] = 'Файла е записан успешно.';
$lang['locfiledit_save_file'] = 'Запис на файла';
$lang['locfiledit_saved_bak'] = 'Архивно копие е създадено (%s)';
$lang['locfiledit_show_default'] = 'Покажи референтния файл:';
$lang['locfiledit_syntax_error'] = 'Синтактична грешка! Файлът не може да бъде записан.';
$lang['locfiledit_webmaster_only'] = 'Само уебмастъри могат да създават и променят локални файлове.';
$lang['Customize CSS'] = 'Къстъмизирайте CSS';
